==============
Flask-Fastx
==============

.. image:: https://codecov.io/gh/tactful-ai/flask-faster-api/branch/main/graph/badge.svg?token=FZJANN69LH
    :target: https://codecov.io/gh/tactful-ai/flask-faster-api
    :alt: Code Coverage
    
.. image:: https://github.com/tactful-ai/flask-faster-api/actions/workflows/python-package.yml/badge.svg
   :target: https://github.com/tactful-ai/flask-faster-api/actions/workflows/python-package.yml
   :alt: CI Tests
.. image:: https://img.shields.io/github/license/tactful-ai/flask-faster-api   
    :alt: License
.. image:: https://img.shields.io/github/stars/tactful-ai/flask-faster-api?style=social   :alt: GitHub Repo stars
.. image:: https://img.shields.io/pypi/pyversions/flask-restx-square  
    :target: https://pypi.org/project/flask-fastx
    :alt: Supported Python versions
   

Flask-Fastx is a Fast API style support for Flask. It Gives you MyPy types with the flexibility of flask.



Compatibility
=============

Flask-Fastx requires Python 3.7+. 



Installation
============

You can install Flask-Fastx with pip:

.. code-block:: console

    $ pip install flask-fastx
    

Quick start
===========

With Flask-Fastx and the autowire decorator feature, parsing path parameters and creating api models is done using only one decorator! 

Before Using Flask-Fastx
================================

.. image:: https://user-images.githubusercontent.com/63073172/130029969-2f59777d-3ad1-423f-bbf1-a8c73d056300.png


After Using Flask-Fastx
================================

.. image:: https://user-images.githubusercontent.com/63073172/130017489-55b0d09d-5ba5-4455-8c88-29878b39e6c5.png




Contributors
============

Flask-Fastx is brought to you by @mfouad, @seifashraf1, @ahmedihabb2, @nadaabdelmaboud, @omargamal253




Contribution
============
Want to contribute? That's awesome! (Details Soon) 
